<?php

namespace Chemical\Looking\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chemical\Looking\Models\Looking;

class LookingPolicy
{

    /**
     * Determine if the given user can view the looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function view(UserPolicy $user, Looking $looking)
    {
        if ($user->canDo('looking.looking.view') && $user->isAdmin()) {
            return true;
        }

        return $looking->user_id == user_id() && $looking->user_type == user_type();
    }

    /**
     * Determine if the given user can create a looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('looking.looking.create');
    }

    /**
     * Determine if the given user can update the given looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function update(UserPolicy $user, Looking $looking)
    {
        if ($user->canDo('looking.looking.edit') && $user->isAdmin()) {
            return true;
        }

        return $looking->user_id == user_id() && $looking->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Looking $looking)
    {
        return $looking->user_id == user_id() && $looking->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Looking $looking)
    {
        if ($user->canDo('looking.looking.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given looking.
     *
     * @param UserPolicy $user
     * @param Looking $looking
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Looking $looking)
    {
        if ($user->canDo('looking.looking.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
